const tools = require("../script/tools");
var onlyOne
cc.Class({
    extends: cc.Component,

    properties: {
        quan: cc.Node,
        tipsAnim: cc.Animation,
        handAnim: cc.Animation,
        sprite: cc.Sprite,
        tipClip: cc.AudioClip,
        btnX: cc.Node
    },

    data: null,

    onLoad() {
        this._playing = false
        this.quan.active = false
        this.tipsAnim.node.active = false
        this.handAnim.node.active = false
        this.btnX.active = false
    },

    onEnable() {
        this.node.on(cc.Node.EventType.TOUCH_START, this.onTouchStart, this)
    },

    onDisable() {
        this.node.off(cc.Node.EventType.TOUCH_START, this.onTouchStart, this)
    },

    initWithData(data, scale) {
        this.data = data
        let rect = this.data.rect
        this.node.x = (rect.x + rect.width / 2) / scale
        this.node.y = (-rect.y - rect.height / 2) / scale
        this.node.width = rect.width / scale
        this.node.height = rect.height / scale
        this.sprite.node.active = false
        if (data.useHand) {
            this.handAnim.node.active = true
            this.handAnim.play()
        }
        let comps = this.getComponentsInChildren(cc.Widget)
        for (let one of comps) {
            one.updateAlignment()
        }
        this.audioId = null
    },

    onTouchStart() {
        if (this._playing) return
        if (this.audioId) return
        if (this.data) {
            this.btnX.active = true
            if (this.data.pic_url && this.data.gIdx == 0) {
                tools.getSpriteFrimeByUrl(this.data.pic_url, (sp) => {
                    this.sprite.spriteFrame = sp
                    this.sprite.node.width = this.node.width
                    this.sprite.node.height = this.node.height
                    this.sprite.node.active = true
                })
            }
            if (this.data.useBorder) {
                this.quan.active = true
            }
            this.handAnim.stop()
            this.handAnim.node.active = false
            if (!this._playing) {
                this._playing = true
                cc.systemEvent.once('stopMusic', this.onStopAudio, this)
                let id = cc.audioEngine.play(this.tipClip)
                cc.audioEngine.setFinishCallback(id, () => {
                    if (onlyOne != this) {
                        this._playing = false
                        return
                    }
                    let url = this.data.audio_url
                    if (url && url != '') {
                        this.playAudio(url)
                    } else {
                        this._playing = false
                    }
                })
            }

            if (onlyOne && onlyOne != this) {
                onlyOne.hideBox()
            }
            onlyOne = this
        }
    },

    onClickHide() {
        this.sprite.node.active = false
        this.hideBox()
    },

    /**隐藏边框 */
    hideBox() {
        this.quan.active = false
        this.btnX.active = false
        this.stopAudio()
    },

    /** 播放音乐 */
    playAudio(url) {
        cc.assetManager.loadRemote(url, (err, audioClip) => {
            if (err) return
            if (!this._playing) return
            this.audioId = cc.audioEngine.play(audioClip, false, 0.8);
            cc.audioEngine.setFinishCallback(this.audioId, this.stopAudio.bind(this));
            this.tipsAnim.node.active = true
            this.tipsAnim.play()
        });
    },

    onStopAudio() {
        this._playing = false
        this.stopAudio()
    },
    stopAudio() {
        this._playing = false
        if (this.audioId != null) {
            cc.audioEngine.stop(this.audioId)
            this.audioId = null
        }
        this.tipsAnim.stop()
        this.tipsAnim.node.active = false
        cc.systemEvent.off('stopMusic', this.onStopAudio, this)
    },
    /** 音频id */
    audioId: null,
});
